pub struct StringWriter {
pub inner: String,
}Expand description
A wrapper for String that implements both Write and WriteColor.
This fixes naga 26.0.0 compatibility where it expects WriteColor on string-like writers. The StringWriter collects written data into an internal String buffer without any color formatting (colors are ignored).
Fields
inner: StringThe internal string buffer that collects written data.
Implementations
Sourceimpl StringWriter
impl StringWriter
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a new StringWriter with the specified capacity.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Consumes the StringWriter and returns the internal String.