pub struct ColorSpec { /* private fields */ }Expand description
A color specification.
Implementations
Sourceimpl ColorSpec
impl ColorSpec
Sourcepub fn set_dimmed(&mut self, yes: bool) -> &mut ColorSpec
pub fn set_dimmed(&mut self, yes: bool) -> &mut ColorSpec
Set whether the text is dimmed or not.
Sourcepub fn set_italic(&mut self, yes: bool) -> &mut ColorSpec
pub fn set_italic(&mut self, yes: bool) -> &mut ColorSpec
Set whether the text is italicized or not.
Sourcepub fn set_underline(&mut self, yes: bool) -> &mut ColorSpec
pub fn set_underline(&mut self, yes: bool) -> &mut ColorSpec
Set whether the text is underlined or not.
Sourcepub fn strikethrough(&self) -> bool
pub fn strikethrough(&self) -> bool
Get whether this is strikethrough or not.
Sourcepub fn set_strikethrough(&mut self, yes: bool) -> &mut ColorSpec
pub fn set_strikethrough(&mut self, yes: bool) -> &mut ColorSpec
Set whether the text is strikethrough or not.
Sourcepub fn reset(&self) -> bool
pub fn reset(&self) -> bool
Get whether reset is enabled or not.
reset is enabled by default. When disabled and using ANSI escape
sequences, a “reset” code will be emitted every time a ColorSpec’s
settings are applied.
Sourcepub fn set_reset(&mut self, yes: bool) -> &mut ColorSpec
pub fn set_reset(&mut self, yes: bool) -> &mut ColorSpec
Set whether to reset the terminal whenever color settings are applied.
reset is enabled by default. When disabled and using ANSI escape
sequences, a “reset” code will be emitted every time a ColorSpec’s
settings are applied.
Typically this is useful if callers have a requirement to more scrupulously manage the exact sequence of escape codes that are emitted when using ANSI for colors.
Sourcepub fn intense(&self) -> bool
pub fn intense(&self) -> bool
Get whether this is intense or not.
On Unix-like systems, this will output the ANSI escape sequence that will print a high-intensity version of the color specified.
On Windows systems, this will output the ANSI escape sequence that will print a brighter version of the color specified.
Sourcepub fn set_intense(&mut self, yes: bool) -> &mut ColorSpec
pub fn set_intense(&mut self, yes: bool) -> &mut ColorSpec
Set whether the text is intense or not.
On Unix-like systems, this will output the ANSI escape sequence that will print a high-intensity version of the color specified.
On Windows systems, this will output the ANSI escape sequence that will print a brighter version of the color specified.