pub struct StandardStream { /* private fields */ }Expand description
A standard stream for writing to stdout or stderr.
This satisfies both io::Write and WriteColor, and buffers writes
until either flush is called or the buffer is full.
Implementations
Sourceimpl StandardStream
impl StandardStream
Sourcepub fn stdout(choice: ColorChoice) -> StandardStream ⓘ
pub fn stdout(choice: ColorChoice) -> StandardStream ⓘ
Create a new StandardStream with the given color preferences that
writes to standard output.
If coloring is desired, ANSI escape sequences are used.
Sourcepub fn stderr(choice: ColorChoice) -> StandardStream ⓘ
pub fn stderr(choice: ColorChoice) -> StandardStream ⓘ
Create a new StandardStream with the given color preferences that
writes to standard error.
If coloring is desired, ANSI escape sequences are used.
Sourcepub fn lock(&self) -> StandardStreamLock<'_> ⓘ
pub fn lock(&self) -> StandardStreamLock<'_> ⓘ
Lock the underlying writer.
The lock guard returned also satisfies io::Write and
WriteColor.
This method is not reentrant. It may panic if lock is called
while a StandardStreamLock is still alive.